@@ -599,7 +599,7 @@ class OculScholarsPortalPreservation(models.Model):
                                              url, bucket=bucket,
                                              s3client=s3client,
                                              decode=False, file=True,
-                                             filename=path)
+                                             filename=str(path))
 
             # local file for testing
             # xml_file = '/home/martin/scholars_portal_keepers_20230202.xml'
@@ -623,8 +623,12 @@ class OculScholarsPortalPreservation(models.Model):
         :return: None
         """
 
+        publisher = 'Undefined' if 'publisher' not in output \
+                                   or output['publisher'] is None \
+            else publisher = output['publisher']
+
         publisher, created = \
-            Publisher.objects.get_or_create(name=output['publisher'])
+            Publisher.objects.get_or_create(name=publisher)
 
         volumes = output['volumes']
         issues = output['issues']
